pub struct PostCommitActivityRecorder {
pub audit: AuditService,
pub events: EventServices,
pub notifications: NotificationService,
}Expand description
Compatibility helper for best-effort work after an operational commit.
This helper does not provide transactional audit durability. An adapter may claim that only when it atomically commits the mutation and local audit or outbox intent in its own store transaction.
Fields
audit: AuditServiceevents: EventServicesnotifications: NotificationServiceImplementations
Sourceimpl PostCommitActivityRecorder
impl PostCommitActivityRecorder
pub async fn record( &self, audit: AuditEvent, event: DomainEvent, notification: Option<Notification>, ) -> Vec<PostCommitActivityWarning>